/*
 * Copyright (c) 2023 Xilinx
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this package; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef __GST_AMA_COMMON_H__
#define __GST_AMA_COMMON_H__

#include <gst/gst.h>

G_BEGIN_DECLS

#define GST_AMA_FORMATS "NV12, I420, NV12_10LE32, P010_10LE, I420_10LE, I420_10BE, RGBP, ARGB, ABGR, RGBA, BGRA, RGB, BGR"

#define GST_AMA_VIDEO_FORMATS "{" GST_AMA_FORMATS "}"

/* Including interchange formats that can't be uploaded/downloaded between host
 * and the device. */
#define GST_AMA_ALL_VIDEO_FORMATS "{ NV12_4L4, " GST_AMA_FORMATS ", NV12_10LE_4L4 }"

#define GST_CAPS_FEATURE_MEMORY_AMA_MEMORY "memory:AMAMemory"

#define GST_AMA_MIN_WIDTH 144
#define GST_AMA_MIN_HEIGHT 144

#define GST_AMA_NUM_SLICES 2

void gst_ama_toggle_memory_caps_feature (GstCaps * caps, gboolean enable);

gint32 gst_ama_device_get_from_caps (GstCaps *caps);
void gst_ama_device_add_to_caps (GstCaps *caps, gint device);
void gst_ama_device_remove_from_caps (GstCaps *caps);

G_END_DECLS

#endif /* __GST_AMA_COMMON_H__ */
